Class: MasterCard::API::McOn::Insurance
- Inherits:
-
Core::Model::BaseObject
- Object
- Core::Model::BaseObject
- MasterCard::API::McOn::Insurance
- Includes:
- Core::Model
- Defined in:
- lib/mastercard/api/mcon/insurance.rb
Class Method Summary collapse
Class Method Details
.getInsuranceClaim(mapObj) ⇒ Object
61 62 63 64 65 66 67 68 69 |
# File 'lib/mastercard/api/mcon/insurance.rb', line 61 def self.getInsuranceClaim(mapObj) # #Creates object of type Insurance # #@param Dict mapObj, containing the required parameters to create a new object #@return [Insurance] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("36867fdb-20af-426a-9620-2bc3ad616a6c", Insurance.new(mapObj)) end |
.tokenizeUserData(mapObj) ⇒ Object
77 78 79 80 81 82 83 84 85 |
# File 'lib/mastercard/api/mcon/insurance.rb', line 77 def self.tokenizeUserData(mapObj) # #Creates object of type Insurance # #@param Dict mapObj, containing the required parameters to create a new object #@return [Insurance] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("37c208be-5494-4533-876d-5c6e81754dd2", Insurance.new(mapObj)) end |