Class: MasterCard::API::McOn::Insurance

Inherits:
Core::Model::BaseObject
  • Object
show all
Includes:
Core::Model
Defined in:
lib/mastercard/api/mcon/insurance.rb

Class Method Summary collapse

Class Method Details

.getInsuranceClaim(mapObj) ⇒ Object



61
62
63
64
65
66
67
68
69
# File 'lib/mastercard/api/mcon/insurance.rb', line 61

def self.getInsuranceClaim(mapObj)
    #
    #Creates object of type Insurance
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [Insurance] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("739c1c7b-29f7-43c6-94c7-d9b73c1d89f6", Insurance.new(mapObj))
end

.tokenizeUserData(mapObj) ⇒ Object



77
78
79
80
81
82
83
84
85
# File 'lib/mastercard/api/mcon/insurance.rb', line 77

def self.tokenizeUserData(mapObj)
    #
    #Creates object of type Insurance
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [Insurance] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("796588c6-b198-4942-89e6-f5a44f41db4f", Insurance.new(mapObj))
end