Class: MasterCard::API::McOn::Offers
- Inherits:
-
Core::Model::BaseObject
- Object
- Core::Model::BaseObject
- MasterCard::API::McOn::Offers
- Includes:
- Core::Model
- Defined in:
- lib/mastercard/api/mcon/offers.rb
Class Method Summary collapse
- .activateOffer(mapObj) ⇒ Object
- .favoriteOffer(mapObj) ⇒ Object
- .getOfferDetail(criteria) ⇒ Object
- .getOffers(criteria) ⇒ Object
- .getPoints(criteria) ⇒ Object
- .getPointsExpiring(criteria) ⇒ Object
- .getRedeemedOffers(criteria) ⇒ Object
- .getVoucherDetail(criteria) ⇒ Object
- .getVouchers(criteria) ⇒ Object
- .redeemOffer(mapObj) ⇒ Object
- .submitOfferPromo(mapObj) ⇒ Object
- .unfavoriteOffer(mapObj) ⇒ Object
- .userOffersRegistrationStatus(criteria) ⇒ Object
Class Method Details
.activateOffer(mapObj) ⇒ Object
89 90 91 92 93 94 95 96 97 |
# File 'lib/mastercard/api/mcon/offers.rb', line 89 def self.activateOffer(mapObj) # #Creates object of type Offers # #@param Dict mapObj, containing the required parameters to create a new object #@return [Offers] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("1f1f8519-5aff-4f05-ae36-3eaad53d2a8f", Offers.new(mapObj)) end |
.favoriteOffer(mapObj) ⇒ Object
122 123 124 125 126 127 128 129 130 |
# File 'lib/mastercard/api/mcon/offers.rb', line 122 def self.favoriteOffer(mapObj) # #Creates object of type Offers # #@param Dict mapObj, containing the required parameters to create a new object #@return [Offers] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("320c950d-3b7c-4988-ae90-e7decd003622", Offers.new(mapObj)) end |
.getOfferDetail(criteria) ⇒ Object
110 111 112 113 114 115 116 117 118 119 |
# File 'lib/mastercard/api/mcon/offers.rb', line 110 def self.getOfferDetail(criteria) # #Query objects of type Offers by id and optional criteria #@param [Dict] criteria #@return [Offers] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("e1a5bf6e-80f0-46a9-89e0-03456a83f50c",Offers.new(criteria)) end |
.getOffers(criteria) ⇒ Object
77 78 79 80 81 82 83 84 85 86 |
# File 'lib/mastercard/api/mcon/offers.rb', line 77 def self.getOffers(criteria) # #Query objects of type Offers by id and optional criteria #@param [Dict] criteria #@return [Offers] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("ff3d410d-f8a8-4bd4-b897-8c7ecb370813",Offers.new(criteria)) end |
.getPoints(criteria) ⇒ Object
225 226 227 228 229 230 231 232 233 234 |
# File 'lib/mastercard/api/mcon/offers.rb', line 225 def self.getPoints(criteria) # #Query objects of type Offers by id and optional criteria #@param [Dict] criteria #@return [Offers] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("3e0bd002-9807-477b-b8a8-78a5d61168bb",Offers.new(criteria)) end |
.getPointsExpiring(criteria) ⇒ Object
208 209 210 211 212 213 214 215 216 217 |
# File 'lib/mastercard/api/mcon/offers.rb', line 208 def self.getPointsExpiring(criteria) # #Query objects of type Offers by id and optional criteria #@param [Dict] criteria #@return [Offers] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("d87f02cb-3440-458a-a465-2e85d9d92bc8",Offers.new(criteria)) end |
.getRedeemedOffers(criteria) ⇒ Object
191 192 193 194 195 196 197 198 199 200 |
# File 'lib/mastercard/api/mcon/offers.rb', line 191 def self.getRedeemedOffers(criteria) # #Query objects of type Offers by id and optional criteria #@param [Dict] criteria #@return [Offers] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("0f94f5b3-8de3-4ede-bf5a-bcc45d4306e5",Offers.new(criteria)) end |
.getVoucherDetail(criteria) ⇒ Object
276 277 278 279 280 281 282 283 284 285 |
# File 'lib/mastercard/api/mcon/offers.rb', line 276 def self.getVoucherDetail(criteria) # #Query objects of type Offers by id and optional criteria #@param [Dict] criteria #@return [Offers] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("21526adf-86f5-45a9-98fe-108d849ef38e",Offers.new(criteria)) end |
.getVouchers(criteria) ⇒ Object
259 260 261 262 263 264 265 266 267 268 |
# File 'lib/mastercard/api/mcon/offers.rb', line 259 def self.getVouchers(criteria) # #Query objects of type Offers by id and optional criteria #@param [Dict] criteria #@return [Offers] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("2d43c13c-9e91-476f-8871-570b3298e586",Offers.new(criteria)) end |
.redeemOffer(mapObj) ⇒ Object
138 139 140 141 142 143 144 145 146 |
# File 'lib/mastercard/api/mcon/offers.rb', line 138 def self.redeemOffer(mapObj) # #Creates object of type Offers # #@param Dict mapObj, containing the required parameters to create a new object #@return [Offers] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("68ab1540-c9ed-4790-9424-f55b05642a82", Offers.new(mapObj)) end |
.submitOfferPromo(mapObj) ⇒ Object
170 171 172 173 174 175 176 177 178 |
# File 'lib/mastercard/api/mcon/offers.rb', line 170 def self.submitOfferPromo(mapObj) # #Creates object of type Offers # #@param Dict mapObj, containing the required parameters to create a new object #@return [Offers] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("9d8d3efb-1be2-42b4-aac7-3e1b8181ad58", Offers.new(mapObj)) end |
.unfavoriteOffer(mapObj) ⇒ Object
154 155 156 157 158 159 160 161 162 |
# File 'lib/mastercard/api/mcon/offers.rb', line 154 def self.unfavoriteOffer(mapObj) # #Creates object of type Offers # #@param Dict mapObj, containing the required parameters to create a new object #@return [Offers] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("159c5daf-c1f2-4aa6-96eb-7a6dc636e904", Offers.new(mapObj)) end |
.userOffersRegistrationStatus(criteria) ⇒ Object
242 243 244 245 246 247 248 249 250 251 |
# File 'lib/mastercard/api/mcon/offers.rb', line 242 def self.userOffersRegistrationStatus(criteria) # #Query objects of type Offers by id and optional criteria #@param [Dict] criteria #@return [Offers] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("0dd5501b-59e3-42fa-8370-ce123dd001ee",Offers.new(criteria)) end |